@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import importlib
+import json
 import os
 import pprint
 import sys
@@ -28,7 +29,11 @@ from dynaconf.vendor import tomllib
 
 os.environ["PYTHONIOENCODING"] = "utf-8"
 
-CWD = Path.cwd()
+CWD = None
+try:
+    CWD = Path.cwd()
+except FileNotFoundError:
+    pass
 EXTS = ["ini", "toml", "yaml", "json", "py", "env"]
 WRITERS = ["ini", "toml", "yaml", "json", "py", "redis", "vault", "env"]
 
@@ -115,6 +120,8 @@ def import_settings(dotted_path):
         module = importlib.import_module(module)
     except ImportError as e:
         raise click.UsageError(e)
+    except FileNotFoundError:
+        return
     try:
         return getattr(module, name)
     except AttributeError as e:
@@ -439,7 +446,10 @@ def init(ctx, fileformat, path, env, _vars, _secrets, wg, y, django):
     is_flag=True,
 )
 def get(key, default, env, unparse):
-    """Returns the raw value for a settings key"""
+    """Returns the raw value for a settings key.
+
+    If result is a dict, list or tuple it is printes as a valid json string.
+    """
     if env:
         env = env.strip()
     if key:
@@ -456,6 +466,9 @@ def get(key, default, env, unparse):
     if unparse:
         result = unparse_conf_data(result)
 
+    if isinstance(result, (dict, list, tuple)):
+        result = json.dumps(result, sort_keys=True)
+
     click.echo(result, nl=False)
 
 
